@@ -3,6 +3,7 @@
 
 import datetime as dt
 import confuse
+import sys
 
 from os import path
 from peewee import (
@@ -14,15 +15,21 @@ from peewee import (
     DateTimeField,
     FloatField,
 )
-
+from playhouse.shortcuts import model_to_dict
 
 DB = None
 
 
-def database():
+def database_path():
     config = confuse.Configuration("pawnstore", __name__)
+    dbname = "pawnstore.sqlite"
+    return path.join(config.config_dir(), dbname)
 
-    return SqliteDatabase(path.join(config.config_dir(), "pawnstore.sqlite"))
+
+def database():
+    if "pytest" in sys.modules:
+        return SqliteDatabase(":memory:")
+    return SqliteDatabase(database_path())
 
 
 class Game(Model):
@@ -56,6 +63,9 @@ class Game(Model):
             (("slug", "website", "user"), True),
         )
 
+    def as_dict(self):
+        return model_to_dict(self)
+
     def __str__(self):
         if self.white:
             return f"{self.user} x {self.opp_name}"
